@@ -13,4 +13,4 @@ from detector_connector import DetectorSettings
 
 @dataclass(kw_only=True, frozen=True)
 class ShiftSettings(DetectorSettings):
-    pass
+    similarity_threshold: float
